@@ -189,23 +189,14 @@ void BridgeWidget::deleteBridge()
 
     if (connection) {
         // qCDebug(PLASMA_NM_EDITOR_LOG) << "About to delete bridged connection" << currentItem->text() << uuid;
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (KMessageBox::questionTwoActions(this,
-#else
-        if (KMessageBox::questionYesNo(this,
-
-#endif
                                             i18n("Do you want to remove the connection '%1'?", connection->name()),
                                             i18n("Remove Connection"),
                                             KStandardGuiItem::remove(),
                                             KStandardGuiItem::cancel(),
                                             QString(),
                                             KMessageBox::Dangerous)
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-            == KMessageBox::Yes) {
-#endif
             connection->remove();
             delete currentItem;
             slotWidgetChanged();
@@ -237,3 +228,5 @@ bool BridgeWidget::isValid() const
 {
     return !m_ui->ifaceName->text().isEmpty() && m_ui->bridges->count() > 0;
 }
+
+#include "moc_bridgewidget.cpp"
